#!/bin/bash
# Script to create a waltz user, generate a key-pair and add the host IP
# for administration

set -eou pipefail

WALTZ_USER=waltz

# Check if the user exists
if id ${WALTZ_USER} > /dev/null 2>&1; then
    echo "user exists"
else
    # Create a local user named waltz if it doesn't exist.
    useradd -c "Waltz User" --create-home -s /bin/bash ${WALTZ_USER}
fi

# Get the home directory of the user
WALTZ_HOME=$(eval echo ~${WALTZ_USER})

# Create .ssh directory if it doesn't exist
mkdir -p ${WALTZ_HOME}/.ssh

# Generate a SSH Key pair for the container to use for administering the host
PKEY=${WALTZ_HOME}/waltz_id_rsa
echo -e 'y\n' | ssh-keygen -t rsa -N "" -f ${PKEY}

# Move the public key to the user
mv ${WALTZ_HOME}/waltz_id_rsa.pub ${WALTZ_HOME}/.ssh/authorized_keys

# Set correct file permissions for ssh
chmod 600 ${PKEY}
chown -R waltz ${WALTZ_HOME}/.ssh
chmod 700 ${WALTZ_HOME}/.ssh
chmod 600 ${WALTZ_HOME}/.ssh/authorized_keys

# Set to ask no password
echo "waltz ALL=(ALL) NOPASSWD: ALL" | sudo tee /etc/sudoers.d/waltz_override

# Get the host ip and put it in hosts file for Ansible to identify the host to
# administer
ip route get 1 | awk '{print $NF;exit}' > ${WALTZ_HOME}/hosts
